# Projeto Giuliana Catti
# Arquivo progr1.r
# Criado em 27/11/14
# Autor: Antonio Carlos P. Lima
setwd("~/Dropbox/CEA/projetos/Giuliana")
dados <- read.csv("dados.csv",sep=",",header=TRUE)
library(survival)
#Gráfico de Sobrevida Global
png("survgeral.png")
plot(survfit(Surv(Tempo,Delta)~1,data=dados),lwd=2, 
     main="Estimador Kaplan-Meier - Sobrevivência Geral",las=1,xlab="Tempo (dias)",ylab="Sobrevivência estimada")
grid()
dev.off()
# Gráfico de Sobrevivência por Tratamento
#survfit(Surv(Tempo,Delta)~Tratamento,data=dados)
png("survtrat.png")
plot(survfit(Surv(Tempo,Delta)~Tratamento,data=dados),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier por Tipo de Tratamento",las=1,xlab="Tempo (dias)",ylab="Sobrevivência estimada")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
dev.off()
#Gráfico de Sobrevivência por Sexo
#survfit(Surv(Tempo,Delta)~Sexo,data=dados)
png("survsexo.png")
plot(survfit(Surv(Tempo,Delta)~Sexo,data=dados),col=c(2,1),lwd=c(2,2),las=1,
     main="Kaplan-Meier por Sexo",las=1,xlab="Tempo (dias)",ylab="Sobrevivência estimada")
legend(5,0.4,col=c(2,1),lwd=c(2,2),legend = c("Fêmeas","Machos"))
grid()
dev.off()
#
#par(mfrow=c(1,2))
#
#Gráfico de Sobrevivência de tratamento para Femeas
#survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='F'))
png("survFemeasxtrat.png")
plot(survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='F')),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier por Tipo de Tratamento\n Fêmeas",las=1,xlab="Tempo (dias)",ylab="Sobrevivência estimada")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
dev.off()
#
#Gráfico de Sobrevivência de tratamento para Machos
#survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='M'))
png("survMachosxtrat.png")
plot(survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='M')),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier por Tipo de Tratamento\n Machos",las=1,xlab="Tempo (dias)",ylab="Sobrevivência estimada")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
dev.off()
#
#
plot(survfit(Surv(Tempo,Delta)~Sexo,data=dados), fun='cloglog',col=c(2,1),lwd=c(2,2),las=1,
     main="Log do risco acumulado - Sexo",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-2, col=c(2,1),lwd=c(2,2),legend = c("Fêmeas","Machos"))
grid()
#
plot(survfit(Surv(Tempo,Delta)~Tratamento,data=dados), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Tratamentos",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-1.8, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
#

plot(survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='F')), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Fêmeas",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-1.5, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
#
plot(survfit(Surv(Tempo,Delta)~Tratamento,data=subset(dados,Sexo=='M')), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Machos",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(132,-1.0, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina","MSC","Pericitos"))
grid()
#
# Modelo de Cox
modelo1 = coxph(Surv(Tempo, Delta) ~ Sexo + Tratamento + Sexo:Tratamento, data = dados)
summary(modelo1)
# Verificacao da suposicao de proporcionalidade dos riscos
timedep.zph = cox.zph(modelo1, transform='log')
timedep.zph
plot(timedep.zph[1])
abline(h=0,lty=3)
plot(timedep.zph[2])
abline(h=0,lty=3)
#
# Recodificacao para entender interacao
#
dados$SSF <- ifelse(dados$Tratamento==0 & dados$Sexo=="F",1,0)
dados$SSM <- ifelse(dados$Tratamento==0 & dados$Sexo=="M",1,0)
dados$MSCF<- ifelse(dados$Tratamento==1 & dados$Sexo=="F",1,0)
dados$MSCM<- ifelse(dados$Tratamento==1 & dados$Sexo=="M",1,0)
dados$PERF<- ifelse(dados$Tratamento==2 & dados$Sexo=="F",1,0)
dados$PERM<- ifelse(dados$Tratamento==2 & dados$Sexo=="M",1,0)

modelo2 = coxph(Surv(Tempo, Delta) ~ SSM + MSCF + MSCM + PERF +PERM, data = dados)
summary(modelo2)

modelo3 = coxph(Surv(Tempo, Delta) ~ SSM + MSCM + PERM, data = dados)
summary(modelo3)

# Teste da razao de verossimilhancas parciais para comparar todos tratamentos para femeas
-2*(modelo3$loglik[2]-modelo2$loglik[2])
pchisq(-2*(modelo3$loglik[2]-modelo2$loglik[2]),2,lower.tail = FALSE)
##

modelo4 = coxph(Surv(Tempo, Delta) ~ MSCF + PERF + I(SSM + MSCM + PERM), data = dados)
summary(modelo4)

# Teste da razao de verossimilhancas parciais para comparar todos tratamentos para machos
-2*(modelo3$loglik[2]-modelo2$loglik[2])
pchisq(-2*(modelo4$loglik[2]-modelo2$loglik[2]),2,lower.tail = FALSE)

modelo4a = coxph(Surv(Tempo,Delta)~ SSM + MSCM + PERM,data=dados)
summary(modelo4a)
modelo5 = coxph(Surv(Tempo, Delta) ~  I(SSM + MSCM) + PERM, data = dados)
summary(modelo5)
# Teste da razao de verossimilhancas parciais para comparar tratamentos SS e MSC para machos
-2*(modelo5$loglik[2]-modelo2$loglik[2])
pchisq(-2*(modelo5$loglik[2]-modelo2$loglik[2]),1,lower.tail = FALSE)

modelo6 = coxph(Surv(Tempo, Delta) ~ I(SSM + PERM) + MSCM, data = dados)
summary(modelo6)
# Teste da razao de verossimilhancas parciais para comparar tratamentos SS e Pericito para machos
-2*(modelo6$loglik[2]-modelo4a$loglik[2])
pchisq(-2*(modelo6$loglik[2]-modelo4a$loglik[2]),1,lower.tail = FALSE)

modelo7 = coxph(Surv(Tempo, Delta) ~ I(SSM + MSCM) + PERM , data = dados)
summary(modelo7)
modelo8 = coxph(Surv(Tempo, Delta) ~ I(SSM + MSCM) , data = dados)
summary(modelo8)

# Teste da razao de verossimilhancas parciais para juntar pericito machos com todos tratamentos para femeas
-2*(modelo8$loglik[2]-modelo7$loglik[2])
pchisq(-2*(modelo8$loglik[2]-modelo7$loglik[2]),1,lower.tail = FALSE)


#modelo final
modelo9 = coxph(Surv(Tempo,Delta) ~ I(SSF + MSCF + PERF + PERM),data=dados)
summary(modelo9)

