# Projeto Giuliana Catti
# Arquivo progr1.r
# Criado em 27/11/14
# Autor: Antonio Carlos P. Lima
setwd("~/Dropbox/CEA/projetos/Giuliana")
dados <- read.csv("Giuliana_SurvivalData.csv",sep=",",header=TRUE)
library(survival)
#Gráfico de Sobrevida Global
pdf("survgeral.pdf")
plot(survfit(Surv(tempo,delta)~1,data=dados),lwd=2, 
     main="Kaplan-Meier Estimates - Complete Data", las=1,xlab="Time in days",ylab="Estimated Survival")
grid()
dev.off()
# Gráfico de Sobrevivência por Tratamento
#survfit(Surv(Tempo,Delta)~Tratamento,data=dados)
#Teste log-rank e Peto-Peto (Gehan-Wilcoxon)
logrank<-survdiff(Surv(tempo,delta)~tratamento, data=dados)
GH<-survdiff(Surv(tempo,delta)~tratamento, data=dados,rho=1)
pvaluelr <- pchisq(q = logrank$chisq,df = 2,lower.tail = FALSE)
pvalueGH <- pchisq(q = GH$chisq,df = 2,lower.tail = FALSE)
#
pdf("survtrat.pdf")
plot(survfit(Surv(tempo,delta)~tratamento,data=dados),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier Estimates by Treatment",las=1,xlab="Time in days",ylab="Estimated Survival")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Hanks' balanced salt solution"," Mesenchymal stem cells"," Perycites"))
mtext(paste("log-rank p-value=",round(pvaluelr,digits=3)),side=1,line=2,adj=0)
mtext(paste("Gehan-Wilcoxon p-value=",round(pvalueGH,digits = 3)),side=1,line=2,adj=1)
grid()
dev.off()
#
#Gráfico de Sobrevivência por Sexo
#survfit(Surv(Tempo,Delta)~Sexo,data=dados)
#Teste log-rank e Peto-Peto (Gehan-Wilcoxon)
logrank<-survdiff(Surv(tempo,delta)~sexo, data=dados)
GH<-survdiff(Surv(tempo,delta)~sexo, data=dados,rho=1)
pvaluelr <- pchisq(q = logrank$chisq,df = 1,lower.tail = FALSE)
pvalueGH <- pchisq(q = GH$chisq,df = 1,lower.tail = FALSE)
#par(mfrow=c(1,2))
#
pdf("survsexo.pdf")
plot(survfit(Surv(tempo,delta)~sexo,data=dados),col=c(2,1),lwd=c(2,2),las=1,
     main="Kaplan-Meier by Sex",las=1,xlab="Time in days",ylab="Estimated Survival")
legend(5,0.4,col=c(2,1),lwd=c(2,2),legend = c("Females","Males"))
mtext(paste("log-rank p-value=",round(pvaluelr,digits=3)),side=1,line=2,adj=0)
mtext(paste("Gehan-Wilcoxon p-value=",round(pvalueGH,digits = 3)),side=1,line=2,adj=1)
grid()
dev.off()
#
#Gráfico de Sobrevivência de tratamento para Femeas
#Teste log-rank e Peto-Peto (Gehan-Wilcoxon)
logrank<-survdiff(Surv(tempo,delta)~tratamento, data=subset(dados,sexo=="F"))
GH<-survdiff(Surv(tempo,delta)~tratamento, data=subset(dados,sexo=="F"),rho=1)
pvaluelr <- pchisq(q = logrank$chisq,df = 2,lower.tail = FALSE)
pvalueGH <- pchisq(q = GH$chisq,df = 2,lower.tail = FALSE)
#
pdf("survFemeasxtrat.pdf")
plot(survfit(Surv(tempo,delta)~tratamento,data=subset(dados,sexo=='F')),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier Estimates by Treatment\n Females",las=1,xlab="Time in days",ylab="Estimated Survival")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Hanks' balanced salt solution"," Mesenchymal stem cells"," Perycites"))
mtext(paste("log-rank p-value=",round(pvaluelr,digits=3)),side=1,line=2,adj=0)
mtext(paste("Gehan-Wilcoxon p-value=",round(pvalueGH,digits = 3)),side=1,line=2,adj=1)
grid()
dev.off()
#
#Gráfico de Sobrevivência de tratamento para Machos
#Teste log-rank e Peto-Peto (Gehan-Wilcoxon)
logrank<-survdiff(Surv(tempo,delta)~tratamento, data=subset(dados,sexo=="M"))
GH<-survdiff(Surv(tempo,delta)~tratamento, data=subset(dados,sexo=="M"),rho=1)
pvaluelr <- pchisq(q = logrank$chisq,df = 2,lower.tail = FALSE)
pvalueGH <- pchisq(q = GH$chisq,df = 2,lower.tail = FALSE)
#
pdf("survMachosxtrat.pdf")
plot(survfit(Surv(tempo,delta)~tratamento,data=subset(dados,sexo=='M')),col=c(1,2,3),lwd=c(2,2,2), 
     main="Kaplan-Meier Estimates by Treatment\n Males",las=1,xlab="Time in days",ylab="Estimated Survival")
legend(5,0.4,col=c(1,2,3),lwd=c(2,2,2),legend = c("Hanks' balanced salt solution"," Mesenchymal stem cells"," Perycites"))
mtext(paste("log-rank p-value=",round(pvaluelr,digits=3)),side=1,line=2,adj=0)
mtext(paste("Gehan-Wilcoxon p-value=",round(pvalueGH,digits = 3)),side=1,line=2,adj=1)
grid()
dev.off()
#
#
plot(survfit(Surv(tempo,delta)~sexo,data=dados), fun='cloglog',col=c(2,1),lwd=c(2,2),las=1,
     main="Log do risco acumulado - Sexo",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-2, col=c(2,1),lwd=c(2,2),legend = c("Fêmeas","Machos"))
grid()
#
plot(survfit(Surv(tempo,delta)~tratamento,data=dados), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Tratamentos",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-1.8, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
#

plot(survfit(Surv(tempo,delta)~tratamento,data=subset(dados,sexo=='F')), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Fêmeas",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(140,-1.5, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina"," MSC"," Pericitos"))
grid()
#
plot(survfit(Surv(tempo,delta)~tratamento,data=subset(dados,sexo=='M')), fun='cloglog',col=c(1,2,3),lwd=c(2,2,2),las=1,
     main="Log do risco acumulado - Machos",xlab="Tempo (dias)", ylab="Log do risco acumulado")
legend(132,-1.0, col=c(1,2,3),lwd=c(2,2,2),legend = c("Solução Salina","MSC","Pericitos"))
grid()
#
# Modelo de Cox
modeloaditivo = coxph(Surv(tempo,delta)~sexo + tratamento, data = dados)
modelo1 = coxph(Surv(tempo, delta) ~ sexo + tratamento + sexo:tratamento, data = dados)
summary(modelo1)
anova(modeloaditivo,modelo1)
# Verificacao da suposicao de proporcionalidade dos riscos
timedep.zph = cox.zph(modelo1, transform='log')
timedep.zph
plot(timedep.zph[1])
abline(h=0,lty=3)
plot(timedep.zph[2])
abline(h=0,lty=3)
#
# Recodificacao para entender interacao
#
dados$SSF <- ifelse(dados$tratamento=="HBSS" & dados$sexo=="F",1,0)
dados$SSM <- ifelse(dados$tratamento=="HBSS" & dados$sexo=="M",1,0)
dados$MSCF<- ifelse(dados$tratamento=="MSC" & dados$sexo=="F",1,0)
dados$MSCM<- ifelse(dados$tratamento=="MSC" & dados$sexo=="M",1,0)
dados$PERF<- ifelse(dados$tratamento=="Pericito" & dados$sexo=="F",1,0)
dados$PERM<- ifelse(dados$tratamento=="Pericito" & dados$sexo=="M",1,0)

modelo2 = coxph(Surv(tempo, delta) ~ SSM + MSCF + MSCM + PERF +PERM, data = dados)
summary(modelo2)

modelo3 = coxph(Surv(tempo, delta) ~ SSM + MSCM + PERM, data = dados)
summary(modelo3)

# Teste da razao de verossimilhancas parciais para comparar todos tratamentos para femeas
anova(modelo2,modelo3)
# -2*(modelo3$loglik[2]-modelo2$loglik[2])
# pchisq(-2*(modelo3$loglik[2]-modelo2$loglik[2]),2,lower.tail = FALSE)
##

modelo4 = coxph(Surv(tempo, delta) ~ I(SSM + MSCM + PERM), data = dados)
summary(modelo4)

# Teste da razao de verossimilhancas parciais para comparar todos tratamentos para machos
anova(modelo3,modelo4)
# -2*(modelo3$loglik[2]-modelo2$loglik[2])
# pchisq(-2*(modelo4$loglik[2]-modelo2$loglik[2]),2,lower.tail = FALSE)

modelo5 = coxph(Surv(tempo, delta) ~ MSCM + PERM, data = dados)
summary(modelo5)
# Teste da razao de verossimilhancas parciais para comparar SS Masc com mulheres todos tratamentos
anova(modelo5, modelo3)
# -2*(modelo5$loglik[2]-modelo2$loglik[2])
# pchisq(-2*(modelo5$loglik[2]-modelo2$loglik[2]),1,lower.tail = FALSE)

modelo6 = coxph(Surv(tempo, delta) ~ SSM + MSCM, data = dados)
summary(modelo6)
# Teste da razao de verossimilhancas parciais para comparar Pericito Masc com mulheres todos tratamentos
anova(modelo6, modelo3)
# -2*(modelo6$loglik[2]-modelo4a$loglik[2])
# pchisq(-2*(modelo6$loglik[2]-modelo4a$loglik[2]),1,lower.tail = FALSE)

modelo7 = coxph(Surv(tempo, delta) ~ SSM + PERM , data = dados)
summary(modelo7)
# Teste da razao de verossimilhancas parciais para comparar MSC Masc com mulheres todos tratamentos
anova(modelo7, modelo3)


modelo8 = coxph(Surv(tempo, delta) ~ I(SSM + MSCM) , data = dados)
summary(modelo8)

# Teste da razao de verossimilhancas parciais para juntar pericito machos com todos tratamentos para femeas
anova(modelo6, modelo8)
#-2*(modelo8$loglik[2]-modelo7$loglik[2])
#pchisq(-2*(modelo8$loglik[2]-modelo7$loglik[2]),1,lower.tail = FALSE)


#modelo final
modelo9 = coxph(Surv(tempo,delta) ~ I(SSM + MSCM),data=dados)
summary(modelo9)

#Curvas de sobrevivencias do modelo ajustado - duas curvas para os dois grupos
dummy <- data.frame(SSM  = c(1 , 0),
                    MSCM = c(0 , 0),
                    PERM = c(0 , 0),
                    SSF  = c(0 , 0),
                    MSCF = c(0 , 0),
                    PERF = c(0 , 0))
pdf("SurvCox.pdf")
plot(survfit(modelo9, newdata=dummy), col=c(4,9),lwd=c(2,2),las=1,
     main="Cox Model Survival Estimates",las=1,xlab="Time in days",ylab="Estimated Survival")
legend(5,0.15,col=c(4,9),lwd=c(2,2),legend = c("Males (MSC or HBSS)","Females (all treatments) and Males Perycites"))
grid()
dev.off()